# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instancegroup/instance_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1.instancegroup import instance_group_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instancegroup_dot_instance__group__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/compute/v1/instancegroup/instance_group_service.proto\x12%yandex.cloud.compute.v1.instancegroup\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a:yandex/cloud/compute/v1/instancegroup/instance_group.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"J\n#ResumeInstanceGroupProcessesRequest\x12#\n\x11instance_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"?\n\"ResumeInstanceGroupProcessMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"I\n\"PauseInstanceGroupProcessesRequest\x12#\n\x11instance_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\">\n!PauseInstanceGroupProcessMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"\x8a\x01\n\x17GetInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x04view\x18\x02 \x01(\x0e\x32\x38.yandex.cloud.compute.v1.instancegroup.InstanceGroupView\"\xcc\x08\n\x1a\x43reateInstanceGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xa2\x01\n\x06labels\x18\x05 \x03(\x0b\x32M.yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12X\n\x11instance_template\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.InstanceTemplateB\x04\xe8\xc7\x31\x01\x12N\n\x0cscale_policy\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.ScalePolicyB\x04\xe8\xc7\x31\x01\x12P\n\rdeploy_policy\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.instancegroup.DeployPolicyB\x04\xe8\xc7\x31\x01\x12X\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AllocationPolicyB\x04\xe8\xc7\x31\x01\x12S\n\x12load_balancer_spec\x18\n \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec\x12S\n\x12health_checks_spec\x18\x0b \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.HealthChecksSpec\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12\x42\n\tvariables\x18\r \x03(\x0b\x32/.yandex.cloud.compute.v1.instancegroup.Variable\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12j\n\x1e\x61pplication_load_balancer_spec\x18\x0f \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x02\x10\x03\"m\n\"CreateInstanceGroupFromYamlRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x13instance_group_yaml\x18\x02 \x01(\tB\x11\xe8\xc7\x31\x01\x8a\xc8\x31\t<=1048576\"B\n\x1b\x43reateInstanceGroupMetadata\x12#\n\x11instance_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x93\t\n\x1aUpdateInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xa2\x01\n\x06labels\x18\x05 \x03(\x0b\x32M.yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12X\n\x11instance_template\x18\x06 \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.InstanceTemplateB\x04\xe8\xc7\x31\x01\x12N\n\x0cscale_policy\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.instancegroup.ScalePolicyB\x04\xe8\xc7\x31\x01\x12P\n\rdeploy_policy\x18\x08 \x01(\x0b\x32\x33.yandex.cloud.compute.v1.instancegroup.DeployPolicyB\x04\xe8\xc7\x31\x01\x12X\n\x11\x61llocation_policy\x18\t \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.AllocationPolicyB\x04\xe8\xc7\x31\x01\x12S\n\x12health_checks_spec\x18\x0b \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.HealthChecksSpec\x12\x1a\n\x12service_account_id\x18\x0c \x01(\t\x12S\n\x12load_balancer_spec\x18\x0e \x01(\x0b\x32\x37.yandex.cloud.compute.v1.instancegroup.LoadBalancerSpec\x12\x42\n\tvariables\x18\x0f \x03(\x0b\x32/.yandex.cloud.compute.v1.instancegroup.Variable\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x12j\n\x1e\x61pplication_load_balancer_spec\x18\x11 \x01(\x0b\x32\x42.yandex.cloud.compute.v1.instancegroup.ApplicationLoadBalancerSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\r\x10\x0eJ\x04\x08\n\x10\x0b\"}\n\"UpdateInstanceGroupFromYamlRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x13instance_group_yaml\x18\x02 \x01(\tB\x11\xe8\xc7\x31\x01\x8a\xc8\x31\t<=1048576\"8\n\x1bUpdateInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"D\n\x19StartInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n\x1aStartInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"C\n\x18StopInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x19StopInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"^\n\x15RollingRestartRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x14managed_instance_ids\x18\x02 \x03(\t\"3\n\x16RollingRestartMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"_\n\x16RollingRecreateRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x14managed_instance_ids\x18\x02 \x03(\t\"4\n\x17RollingRecreateMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"E\n\x1a\x44\x65leteInstanceGroupRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"8\n\x1b\x44\x65leteInstanceGroupMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"4\n\x17\x44\x65leteInstancesMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"2\n\x15StopInstancesMetadata\x12\x19\n\x11instance_group_id\x18\x01 \x01(\t\"\xd7\x01\n\x19ListInstanceGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x46\n\x04view\x18\x05 \x01(\x0e\x32\x38.yandex.cloud.compute.v1.instancegroup.InstanceGroupView\"\x84\x01\n\x1aListInstanceGroupsResponse\x12M\n\x0finstance_groups\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.compute.v1.instancegroup.InstanceGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa7\x01\n!ListInstanceGroupInstancesRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x88\x01\n\"ListInstanceGroupInstancesResponse\x12I\n\tinstances\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.instancegroup.ManagedInstance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x88\x01\n\x16\x44\x65leteInstancesRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\x14managed_instance_ids\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x03>=1\x8a\xc8\x31\x04<=50\x12\x16\n\x0e\x63reate_another\x18\x03 \x01(\x08\"n\n\x14StopInstancesRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12-\n\x14managed_instance_ids\x18\x02 \x03(\tB\x0f\x82\xc8\x31\x03>=1\x8a\xc8\x31\x04<=50\"\xa8\x01\n\"ListInstanceGroupOperationsRequest\x12\'\n\x11instance_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"u\n#ListInstanceGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa0\x01\n\"ListInstanceGroupLogRecordsRequest\x12\x1f\n\x11instance_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x85\x01\n#ListInstanceGroupLogRecordsResponse\x12\x45\n\x0blog_records\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.compute.v1.instancegroup.LogRecord\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*(\n\x11InstanceGroupView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\x84$\n\x14InstanceGroupService\x12\xb3\x01\n\x03Get\x12>.yandex.cloud.compute.v1.instancegroup.GetInstanceGroupRequest\x1a\x34.yandex.cloud.compute.v1.instancegroup.InstanceGroup\"6\x82\xd3\xe4\x93\x02\x30\x12./compute/v1/instanceGroups/{instance_group_id}\x12\xaf\x01\n\x04List\x12@.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsRequest\x1a\x41.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/compute/v1/instanceGroups\x12\xc5\x01\n\x06\x43reate\x12\x41.yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*,\n\x1b\x43reateInstanceGroupMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x1f\"\x1a/compute/v1/instanceGroups:\x01*\x12\xda\x01\n\x0e\x43reateFromYaml\x12I.yandex.cloud.compute.v1.instancegroup.CreateInstanceGroupFromYamlRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*,\n\x1b\x43reateInstanceGroupMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02$\"\x1f/compute/v1/instanceGroups:yaml:\x01*\x12\xd9\x01\n\x06Update\x12\x41.yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*,\n\x1bUpdateInstanceGroupMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x33\x32./compute/v1/instanceGroups/{instance_group_id}:\x01*\x12\xee\x01\n\x0eUpdateFromYaml\x12I.yandex.cloud.compute.v1.instancegroup.UpdateInstanceGroupFromYamlRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*,\n\x1bUpdateInstanceGroupMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x38\x32\x33/compute/v1/instanceGroups/{instance_group_id}:yaml:\x01*\x12\xd5\x01\n\x04Stop\x12?.yandex.cloud.compute.v1.instancegroup.StopInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2**\n\x19StopInstanceGroupMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x35\"3/compute/v1/instanceGroups/{instance_group_id}:stop\x12\xe6\x01\n\x0eRollingRestart\x12<.yandex.cloud.compute.v1.instancegroup.RollingRestartRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*\'\n\x16RollingRestartMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x42\"=/compute/v1/instanceGroups/{instance_group_id}:rollingRestart:\x01*\x12\xea\x01\n\x0fRollingRecreate\x12=.yandex.cloud.compute.v1.instancegroup.RollingRecreateRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*(\n\x17RollingRecreateMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x43\">/compute/v1/instanceGroups/{instance_group_id}:rollingRecreate:\x01*\x12\xd9\x01\n\x05Start\x12@.yandex.cloud.compute.v1.instancegroup.StartInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*+\n\x1aStartInstanceGroupMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x36\"4/compute/v1/instanceGroups/{instance_group_id}:start\x12\xde\x01\n\x06\x44\x65lete\x12\x41.yandex.cloud.compute.v1.instancegroup.DeleteInstanceGroupRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*4\n\x1b\x44\x65leteInstanceGroupMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x30*./compute/v1/instanceGroups/{instance_group_id}\x12\xe6\x01\n\rListInstances\x12H.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesRequest\x1aI.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupInstancesResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/compute/v1/instanceGroups/{instance_group_id}/instances\x12\xa1\x01\n\x0f\x44\x65leteInstances\x12=.yandex.cloud.compute.v1.instancegroup.DeleteInstancesRequest\x1a!.yandex.cloud.operation.Operation\",\xb2\xd2*(\n\x17\x44\x65leteInstancesMetadata\x12\rInstanceGroup\x12\x9b\x01\n\rStopInstances\x12;.yandex.cloud.compute.v1.instancegroup.StopInstancesRequest\x1a!.yandex.cloud.operation.Operation\"*\xb2\xd2*&\n\x15StopInstancesMetadata\x12\rInstanceGroup\x12\xea\x01\n\x0eListOperations\x12I.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsRequest\x1aJ.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupOperationsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/compute/v1/instanceGroups/{instance_group_id}/operations\x12\xe4\x01\n\x0eListLogRecords\x12I.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsRequest\x1aJ.yandex.cloud.compute.v1.instancegroup.ListInstanceGroupLogRecordsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/compute/v1/instanceGroups/{instance_group_id}:logs\x12\xba\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"C\x82\xd3\xe4\x93\x02=\x12;/compute/v1/instanceGroups/{resource_id}:listAccessBindings\x12\xea\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?\":/compute/v1/instanceGroups/{resource_id}:setAccessBindings:\x01*\x12\xf6\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42\"=/compute/v1/instanceGroups/{resource_id}:updateAccessBindings:\x01*\x12\x83\x02\n\x0fResumeProcesses\x12J.yandex.cloud.compute.v1.instancegroup.ResumeInstanceGroupProcessesRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*3\n\"ResumeInstanceGroupProcessMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x43\">/compute/v1/instanceGroups/{instance_group_id}:resumeProcesses:\x01*\x12\xfe\x01\n\x0ePauseProcesses\x12I.yandex.cloud.compute.v1.instancegroup.PauseInstanceGroupProcessesRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*2\n!PauseInstanceGroupProcessMetadata\x12\rInstanceGroup\x82\xd3\xe4\x93\x02\x42\"=/compute/v1/instanceGroups/{instance_group_id}:pauseProcesses:\x01*B\x84\x01\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.instancegroup.instance_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.compute.v1.instancegroupZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1/instancegroup;instancegroup'
  _RESUMEINSTANCEGROUPPROCESSESREQUEST.fields_by_name['instance_group_id']._options = None
  _RESUMEINSTANCEGROUPPROCESSESREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\212\3101\004<=50'
  _PAUSEINSTANCEGROUPPROCESSESREQUEST.fields_by_name['instance_group_id']._options = None
  _PAUSEINSTANCEGROUPPROCESSESREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\212\3101\004<=50'
  _GETINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
  _GETINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEINSTANCEGROUPREQUEST_LABELSENTRY._options = None
  _CREATEINSTANCEGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['folder_id']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['name']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['description']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['labels']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['instance_template']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['instance_template']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy']._options = None
  _CREATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['folder_id']._options = None
  _CREATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_yaml']._options = None
  _CREATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_yaml']._serialized_options = b'\350\3071\001\212\3101\t<=1048576'
  _CREATEINSTANCEGROUPMETADATA.fields_by_name['instance_group_id']._options = None
  _CREATEINSTANCEGROUPMETADATA.fields_by_name['instance_group_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEINSTANCEGROUPREQUEST_LABELSENTRY._options = None
  _UPDATEINSTANCEGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['name']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['description']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['labels']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_template']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['instance_template']._serialized_options = b'\350\3071\001'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['scale_policy']._serialized_options = b'\350\3071\001'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['deploy_policy']._serialized_options = b'\350\3071\001'
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy']._options = None
  _UPDATEINSTANCEGROUPREQUEST.fields_by_name['allocation_policy']._serialized_options = b'\350\3071\001'
  _UPDATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_id']._options = None
  _UPDATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_yaml']._options = None
  _UPDATEINSTANCEGROUPFROMYAMLREQUEST.fields_by_name['instance_group_yaml']._serialized_options = b'\350\3071\001\212\3101\t<=1048576'
  _STARTINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
  _STARTINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
  _STOPINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ROLLINGRESTARTREQUEST.fields_by_name['instance_group_id']._options = None
  _ROLLINGRESTARTREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ROLLINGRECREATEREQUEST.fields_by_name['instance_group_id']._options = None
  _ROLLINGRECREATEREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._options = None
  _DELETEINSTANCEGROUPREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['filter']._options = None
  _LISTINSTANCEGROUPSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['instance_group_id']._options = None
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['page_size']._options = None
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['page_token']._options = None
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['filter']._options = None
  _LISTINSTANCEGROUPINSTANCESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _DELETEINSTANCESREQUEST.fields_by_name['instance_group_id']._options = None
  _DELETEINSTANCESREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEINSTANCESREQUEST.fields_by_name['managed_instance_ids']._options = None
  _DELETEINSTANCESREQUEST.fields_by_name['managed_instance_ids']._serialized_options = b'\202\3101\003>=1\212\3101\004<=50'
  _STOPINSTANCESREQUEST.fields_by_name['instance_group_id']._options = None
  _STOPINSTANCESREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPINSTANCESREQUEST.fields_by_name['managed_instance_ids']._options = None
  _STOPINSTANCESREQUEST.fields_by_name['managed_instance_ids']._serialized_options = b'\202\3101\003>=1\212\3101\004<=50'
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['instance_group_id']._options = None
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTINSTANCEGROUPOPERATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['instance_group_id']._options = None
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['instance_group_id']._serialized_options = b'\350\3071\001'
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['page_size']._options = None
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['page_token']._options = None
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['filter']._options = None
  _LISTINSTANCEGROUPLOGRECORDSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _INSTANCEGROUPSERVICE.methods_by_name['Get']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0020\022./compute/v1/instanceGroups/{instance_group_id}'
  _INSTANCEGROUPSERVICE.methods_by_name['List']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/compute/v1/instanceGroups'
  _INSTANCEGROUPSERVICE.methods_by_name['Create']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*,\n\033CreateInstanceGroupMetadata\022\rInstanceGroup\202\323\344\223\002\037\"\032/compute/v1/instanceGroups:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['CreateFromYaml']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['CreateFromYaml']._serialized_options = b'\262\322*,\n\033CreateInstanceGroupMetadata\022\rInstanceGroup\202\323\344\223\002$\"\037/compute/v1/instanceGroups:yaml:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['Update']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*,\n\033UpdateInstanceGroupMetadata\022\rInstanceGroup\202\323\344\223\00232./compute/v1/instanceGroups/{instance_group_id}:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['UpdateFromYaml']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['UpdateFromYaml']._serialized_options = b'\262\322*,\n\033UpdateInstanceGroupMetadata\022\rInstanceGroup\202\323\344\223\002823/compute/v1/instanceGroups/{instance_group_id}:yaml:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['Stop']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['Stop']._serialized_options = b'\262\322**\n\031StopInstanceGroupMetadata\022\rInstanceGroup\202\323\344\223\0025\"3/compute/v1/instanceGroups/{instance_group_id}:stop'
  _INSTANCEGROUPSERVICE.methods_by_name['RollingRestart']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['RollingRestart']._serialized_options = b'\262\322*\'\n\026RollingRestartMetadata\022\rInstanceGroup\202\323\344\223\002B\"=/compute/v1/instanceGroups/{instance_group_id}:rollingRestart:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['RollingRecreate']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['RollingRecreate']._serialized_options = b'\262\322*(\n\027RollingRecreateMetadata\022\rInstanceGroup\202\323\344\223\002C\">/compute/v1/instanceGroups/{instance_group_id}:rollingRecreate:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['Start']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['Start']._serialized_options = b'\262\322*+\n\032StartInstanceGroupMetadata\022\rInstanceGroup\202\323\344\223\0026\"4/compute/v1/instanceGroups/{instance_group_id}:start'
  _INSTANCEGROUPSERVICE.methods_by_name['Delete']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*4\n\033DeleteInstanceGroupMetadata\022\025google.protobuf.Empty\202\323\344\223\0020*./compute/v1/instanceGroups/{instance_group_id}'
  _INSTANCEGROUPSERVICE.methods_by_name['ListInstances']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['ListInstances']._serialized_options = b'\202\323\344\223\002:\0228/compute/v1/instanceGroups/{instance_group_id}/instances'
  _INSTANCEGROUPSERVICE.methods_by_name['DeleteInstances']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['DeleteInstances']._serialized_options = b'\262\322*(\n\027DeleteInstancesMetadata\022\rInstanceGroup'
  _INSTANCEGROUPSERVICE.methods_by_name['StopInstances']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['StopInstances']._serialized_options = b'\262\322*&\n\025StopInstancesMetadata\022\rInstanceGroup'
  _INSTANCEGROUPSERVICE.methods_by_name['ListOperations']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002;\0229/compute/v1/instanceGroups/{instance_group_id}/operations'
  _INSTANCEGROUPSERVICE.methods_by_name['ListLogRecords']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['ListLogRecords']._serialized_options = b'\202\323\344\223\0025\0223/compute/v1/instanceGroups/{instance_group_id}:logs'
  _INSTANCEGROUPSERVICE.methods_by_name['ListAccessBindings']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002=\022;/compute/v1/instanceGroups/{resource_id}:listAccessBindings'
  _INSTANCEGROUPSERVICE.methods_by_name['SetAccessBindings']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002?\":/compute/v1/instanceGroups/{resource_id}:setAccessBindings:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002B\"=/compute/v1/instanceGroups/{resource_id}:updateAccessBindings:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['ResumeProcesses']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['ResumeProcesses']._serialized_options = b'\262\322*3\n\"ResumeInstanceGroupProcessMetadata\022\rInstanceGroup\202\323\344\223\002C\">/compute/v1/instanceGroups/{instance_group_id}:resumeProcesses:\001*'
  _INSTANCEGROUPSERVICE.methods_by_name['PauseProcesses']._options = None
  _INSTANCEGROUPSERVICE.methods_by_name['PauseProcesses']._serialized_options = b'\262\322*2\n!PauseInstanceGroupProcessMetadata\022\rInstanceGroup\202\323\344\223\002B\"=/compute/v1/instanceGroups/{instance_group_id}:pauseProcesses:\001*'
  _globals['_INSTANCEGROUPVIEW']._serialized_start=5723
  _globals['_INSTANCEGROUPVIEW']._serialized_end=5763
  _globals['_RESUMEINSTANCEGROUPPROCESSESREQUEST']._serialized_start=372
  _globals['_RESUMEINSTANCEGROUPPROCESSESREQUEST']._serialized_end=446
  _globals['_RESUMEINSTANCEGROUPPROCESSMETADATA']._serialized_start=448
  _globals['_RESUMEINSTANCEGROUPPROCESSMETADATA']._serialized_end=511
  _globals['_PAUSEINSTANCEGROUPPROCESSESREQUEST']._serialized_start=513
  _globals['_PAUSEINSTANCEGROUPPROCESSESREQUEST']._serialized_end=586
  _globals['_PAUSEINSTANCEGROUPPROCESSMETADATA']._serialized_start=588
  _globals['_PAUSEINSTANCEGROUPPROCESSMETADATA']._serialized_end=650
  _globals['_GETINSTANCEGROUPREQUEST']._serialized_start=653
  _globals['_GETINSTANCEGROUPREQUEST']._serialized_end=791
  _globals['_CREATEINSTANCEGROUPREQUEST']._serialized_start=794
  _globals['_CREATEINSTANCEGROUPREQUEST']._serialized_end=1894
  _globals['_CREATEINSTANCEGROUPREQUEST_LABELSENTRY']._serialized_start=1843
  _globals['_CREATEINSTANCEGROUPREQUEST_LABELSENTRY']._serialized_end=1888
  _globals['_CREATEINSTANCEGROUPFROMYAMLREQUEST']._serialized_start=1896
  _globals['_CREATEINSTANCEGROUPFROMYAMLREQUEST']._serialized_end=2005
  _globals['_CREATEINSTANCEGROUPMETADATA']._serialized_start=2007
  _globals['_CREATEINSTANCEGROUPMETADATA']._serialized_end=2073
  _globals['_UPDATEINSTANCEGROUPREQUEST']._serialized_start=2076
  _globals['_UPDATEINSTANCEGROUPREQUEST']._serialized_end=3247
  _globals['_UPDATEINSTANCEGROUPREQUEST_LABELSENTRY']._serialized_start=1843
  _globals['_UPDATEINSTANCEGROUPREQUEST_LABELSENTRY']._serialized_end=1888
  _globals['_UPDATEINSTANCEGROUPFROMYAMLREQUEST']._serialized_start=3249
  _globals['_UPDATEINSTANCEGROUPFROMYAMLREQUEST']._serialized_end=3374
  _globals['_UPDATEINSTANCEGROUPMETADATA']._serialized_start=3376
  _globals['_UPDATEINSTANCEGROUPMETADATA']._serialized_end=3432
  _globals['_STARTINSTANCEGROUPREQUEST']._serialized_start=3434
  _globals['_STARTINSTANCEGROUPREQUEST']._serialized_end=3502
  _globals['_STARTINSTANCEGROUPMETADATA']._serialized_start=3504
  _globals['_STARTINSTANCEGROUPMETADATA']._serialized_end=3559
  _globals['_STOPINSTANCEGROUPREQUEST']._serialized_start=3561
  _globals['_STOPINSTANCEGROUPREQUEST']._serialized_end=3628
  _globals['_STOPINSTANCEGROUPMETADATA']._serialized_start=3630
  _globals['_STOPINSTANCEGROUPMETADATA']._serialized_end=3684
  _globals['_ROLLINGRESTARTREQUEST']._serialized_start=3686
  _globals['_ROLLINGRESTARTREQUEST']._serialized_end=3780
  _globals['_ROLLINGRESTARTMETADATA']._serialized_start=3782
  _globals['_ROLLINGRESTARTMETADATA']._serialized_end=3833
  _globals['_ROLLINGRECREATEREQUEST']._serialized_start=3835
  _globals['_ROLLINGRECREATEREQUEST']._serialized_end=3930
  _globals['_ROLLINGRECREATEMETADATA']._serialized_start=3932
  _globals['_ROLLINGRECREATEMETADATA']._serialized_end=3984
  _globals['_DELETEINSTANCEGROUPREQUEST']._serialized_start=3986
  _globals['_DELETEINSTANCEGROUPREQUEST']._serialized_end=4055
  _globals['_DELETEINSTANCEGROUPMETADATA']._serialized_start=4057
  _globals['_DELETEINSTANCEGROUPMETADATA']._serialized_end=4113
  _globals['_DELETEINSTANCESMETADATA']._serialized_start=4115
  _globals['_DELETEINSTANCESMETADATA']._serialized_end=4167
  _globals['_STOPINSTANCESMETADATA']._serialized_start=4169
  _globals['_STOPINSTANCESMETADATA']._serialized_end=4219
  _globals['_LISTINSTANCEGROUPSREQUEST']._serialized_start=4222
  _globals['_LISTINSTANCEGROUPSREQUEST']._serialized_end=4437
  _globals['_LISTINSTANCEGROUPSRESPONSE']._serialized_start=4440
  _globals['_LISTINSTANCEGROUPSRESPONSE']._serialized_end=4572
  _globals['_LISTINSTANCEGROUPINSTANCESREQUEST']._serialized_start=4575
  _globals['_LISTINSTANCEGROUPINSTANCESREQUEST']._serialized_end=4742
  _globals['_LISTINSTANCEGROUPINSTANCESRESPONSE']._serialized_start=4745
  _globals['_LISTINSTANCEGROUPINSTANCESRESPONSE']._serialized_end=4881
  _globals['_DELETEINSTANCESREQUEST']._serialized_start=4884
  _globals['_DELETEINSTANCESREQUEST']._serialized_end=5020
  _globals['_STOPINSTANCESREQUEST']._serialized_start=5022
  _globals['_STOPINSTANCESREQUEST']._serialized_end=5132
  _globals['_LISTINSTANCEGROUPOPERATIONSREQUEST']._serialized_start=5135
  _globals['_LISTINSTANCEGROUPOPERATIONSREQUEST']._serialized_end=5303
  _globals['_LISTINSTANCEGROUPOPERATIONSRESPONSE']._serialized_start=5305
  _globals['_LISTINSTANCEGROUPOPERATIONSRESPONSE']._serialized_end=5422
  _globals['_LISTINSTANCEGROUPLOGRECORDSREQUEST']._serialized_start=5425
  _globals['_LISTINSTANCEGROUPLOGRECORDSREQUEST']._serialized_end=5585
  _globals['_LISTINSTANCEGROUPLOGRECORDSRESPONSE']._serialized_start=5588
  _globals['_LISTINSTANCEGROUPLOGRECORDSRESPONSE']._serialized_end=5721
  _globals['_INSTANCEGROUPSERVICE']._serialized_start=5766
  _globals['_INSTANCEGROUPSERVICE']._serialized_end=10378
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/validation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dyandex/cloud/validation.proto\x12\x0cyandex.cloud\x1a google/protobuf/descriptor.proto\"<\n\nMapKeySpec\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12\x0e\n\x06length\x18\x03 \x01(\t:4\n\x0b\x65xactly_one\x12\x1d.google.protobuf.OneofOptions\x18\x98\x98\x06 \x01(\x08:1\n\x08required\x12\x1d.google.protobuf.FieldOptions\x18\xfd\x98\x06 \x01(\x08:0\n\x07pattern\x12\x1d.google.protobuf.FieldOptions\x18\xfe\x98\x06 \x01(\t:.\n\x05value\x12\x1d.google.protobuf.FieldOptions\x18\xff\x98\x06 \x01(\t:-\n\x04size\x12\x1d.google.protobuf.FieldOptions\x18\x80\x99\x06 \x01(\t:/\n\x06length\x12\x1d.google.protobuf.FieldOptions\x18\x81\x99\x06 \x01(\t:/\n\x06unique\x12\x1d.google.protobuf.FieldOptions\x18\x82\x99\x06 \x01(\x08:J\n\x07map_key\x12\x1d.google.protobuf.FieldOptions\x18\x86\x99\x06 \x01(\x0b\x32\x18.yandex.cloud.MapKeySpec:.\n\x05\x62ytes\x12\x1d.google.protobuf.FieldOptions\x18\x87\x99\x06 \x01(\tBJ\n\x10yandex.cloud.apiZ6github.com/yandex-cloud/go-genproto/yandex/cloud;cloudb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.validation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020yandex.cloud.apiZ6github.com/yandex-cloud/go-genproto/yandex/cloud;cloud'
  _globals['_MAPKEYSPEC']._serialized_start=81
  _globals['_MAPKEYSPEC']._serialized_end=141
# @@protoc_insertion_point(module_scope)



import logging
from importlib.metadata import PackageNotFoundError, version
from typing import Dict, Optional

import grpc

from yandex.cloud.endpoint.api_endpoint_service_pb2 import ListApiEndpointsRequest
from yandex.cloud.endpoint.api_endpoint_service_pb2_grpc import ApiEndpointServiceStub
from yandexcloud import _auth_plugin
from yandexcloud._auth_fabric import YC_API_ENDPOINT, get_auth_token_requester

try:
    VERSION = version("yandexcloud")
except PackageNotFoundError:
    VERSION = "0.0.0"

SDK_USER_AGENT = "yandex-cloud-python-sdk/{version}".format(version=VERSION)
logger = logging.getLogger(__name__)


class Channels:
    def __init__(self, client_user_agent=None, endpoints: Optional[Dict[str, str]] = None, **kwargs):
        self._channel_creds = grpc.ssl_channel_credentials(
            root_certificates=kwargs.get("root_certificates"),
            private_key=kwargs.get("private_key"),
            certificate_chain=kwargs.get("certificate_chain"),
        )
        self._endpoint = kwargs.get("endpoint", YC_API_ENDPOINT)
        self._token_requester = get_auth_token_requester(
            token=kwargs.get("token"),
            service_account_key=kwargs.get("service_account_key"),
            iam_token=kwargs.get("iam_token"),
            endpoint=self._endpoint,
        )

        self._client_user_agent = client_user_agent
        self._config_endpoints = endpoints if endpoints is not None else {}
        self._endpoints = None
        self.channel_options = tuple(
            ("grpc.primary_user_agent", user_agent)
            for user_agent in [self._client_user_agent, SDK_USER_AGENT]
            if user_agent is not None
        )

    def channel(self, service: str, endpoint: Optional[str] = None, insecure: bool = False) -> grpc.Channel:
        if endpoint:
            logger.info("Using provided service %s endpoint %s", service, endpoint)
            if insecure:
                logger.info("Insecure option is ON, no IAM endpoint used for verification")
                return grpc.insecure_channel(endpoint, options=self.channel_options)
            logger.info("Insecure option is OFF,IAM endpoint %s used for verification")
            creds = self._get_creds(self.endpoints["iam"])
            return grpc.secure_channel(endpoint, creds, options=self.channel_options)
        if service not in self._config_endpoints and insecure:
            logger.warning(
                "Unable to use insecure option for default {%s} service endpoint.\n"
                "Option is ignored. To enable it override endpoint.",
                service,
            )
        elif insecure:
            logger.info("Insecure option is ON, no IAM endpoint used for verification")
            return grpc.insecure_channel(self.endpoints[service], options=self.channel_options)

        logger.info(
            "Using endpoints from configuration, IAM %s, %s %s",
            self.endpoints["iam"],
            service,
            self.endpoints[service],
        )

        creds = self._get_creds(self.endpoints["iam"])
        if service not in self.endpoints:
            raise RuntimeError(f"Unknown service: {service}")
        return grpc.secure_channel(self.endpoints[service], creds, options=self.channel_options)

    @property
    def endpoints(self) -> Optional[dict]:
        if self._endpoints is None:
            self._endpoints = self._get_endpoints()
            for id_, address in self._config_endpoints.items():
                logger.debug("Override service %s, endpoint %s", id_, address)
                if id_ == "iam":
                    logger.warning(
                        "Be aware `iam` service endpoint is overridden. "
                        "That can produce unexpected results in SDK calls."
                    )
                self._endpoints[id_] = address
        return self._endpoints

    def _get_endpoints(self) -> Dict[str, str]:
        unauthenticated_channel = grpc.secure_channel(self._endpoint, self._channel_creds, options=self.channel_options)
        endpoint_service = ApiEndpointServiceStub(unauthenticated_channel)
        resp = endpoint_service.List(ListApiEndpointsRequest())
        return {endpoint.id: endpoint.address for endpoint in resp.endpoints}

    def _get_creds(self, iam_endpoint: str) -> grpc.ChannelCredentials:
        plugin = _auth_plugin.Credentials(self._token_requester, lambda: iam_endpoint)
        call_creds = grpc.metadata_call_credentials(plugin)
        creds = grpc.composite_channel_credentials(self._channel_creds, call_creds)
        return creds



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.ai.llm.v1alpha import llm_service_pb2 as yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class TextGenerationServiceStub(object):
    """Service for text generation and conversation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Instruct = channel.unary_stream(
                '/yandex.cloud.ai.llm.v1alpha.TextGenerationService/Instruct',
                request_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructResponse.FromString,
                )
        self.Chat = channel.unary_stream(
                '/yandex.cloud.ai.llm.v1alpha.TextGenerationService/Chat',
                request_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.ChatRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.ChatResponse.FromString,
                )


class TextGenerationServiceServicer(object):
    """Service for text generation and conversation.
    """

    def Instruct(self, request, context):
        """RPC method for instructing the model to generate text.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Chat(self, request, context):
        """RPC method for engaging in a chat conversation with the model.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextGenerationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Instruct': grpc.unary_stream_rpc_method_handler(
                    servicer.Instruct,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructResponse.SerializeToString,
            ),
            'Chat': grpc.unary_stream_rpc_method_handler(
                    servicer.Chat,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.ChatRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.ChatResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.llm.v1alpha.TextGenerationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextGenerationService(object):
    """Service for text generation and conversation.
    """

    @staticmethod
    def Instruct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.ai.llm.v1alpha.TextGenerationService/Instruct',
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Chat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/yandex.cloud.ai.llm.v1alpha.TextGenerationService/Chat',
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.ChatRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.ChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class TokenizerServiceStub(object):
    """Service for tokenizing input text.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tokenize = channel.unary_unary(
                '/yandex.cloud.ai.llm.v1alpha.TokenizerService/Tokenize',
                request_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.TokenizeRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.TokenizeResponse.FromString,
                )


class TokenizerServiceServicer(object):
    """Service for tokenizing input text.
    """

    def Tokenize(self, request, context):
        """RPC method for tokenizing input text.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TokenizerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Tokenize': grpc.unary_unary_rpc_method_handler(
                    servicer.Tokenize,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.TokenizeRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.TokenizeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.llm.v1alpha.TokenizerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TokenizerService(object):
    """Service for tokenizing input text.
    """

    @staticmethod
    def Tokenize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.llm.v1alpha.TokenizerService/Tokenize',
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.TokenizeRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.TokenizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class EmbeddingsServiceStub(object):
    """Service for obtaining embeddings for text data.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Embedding = channel.unary_unary(
                '/yandex.cloud.ai.llm.v1alpha.EmbeddingsService/Embedding',
                request_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.EmbeddingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.EmbeddingResponse.FromString,
                )


class EmbeddingsServiceServicer(object):
    """Service for obtaining embeddings for text data.
    """

    def Embedding(self, request, context):
        """RPC method to obtain embeddings for input text data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EmbeddingsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Embedding': grpc.unary_unary_rpc_method_handler(
                    servicer.Embedding,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.EmbeddingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.EmbeddingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.llm.v1alpha.EmbeddingsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EmbeddingsService(object):
    """Service for obtaining embeddings for text data.
    """

    @staticmethod
    def Embedding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.llm.v1alpha.EmbeddingsService/Embedding',
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.EmbeddingRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.EmbeddingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class TextGenerationAsyncServiceStub(object):
    """Service for asynchronous text generation.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Instruct = channel.unary_unary(
                '/yandex.cloud.ai.llm.v1alpha.TextGenerationAsyncService/Instruct',
                request_serializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class TextGenerationAsyncServiceServicer(object):
    """Service for asynchronous text generation.
    """

    def Instruct(self, request, context):
        """RPC method for instructing the model to generate text.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TextGenerationAsyncServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Instruct': grpc.unary_unary_rpc_method_handler(
                    servicer.Instruct,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.llm.v1alpha.TextGenerationAsyncService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TextGenerationAsyncService(object):
    """Service for asynchronous text generation.
    """

    @staticmethod
    def Instruct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.ai.llm.v1alpha.TextGenerationAsyncService/Instruct',
            yandex_dot_cloud_dot_ai_dot_llm_dot_v1alpha_dot_llm__service__pb2.InstructRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/budget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/billing/v1/budget.proto\x12\x17yandex.cloud.billing.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x86\x03\n\x06\x42udget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12\x62illing_account_id\x18\x04 \x01(\t\x12\x35\n\x06status\x18\x05 \x01(\x0e\x32%.yandex.cloud.billing.v1.BudgetStatus\x12>\n\x0b\x63ost_budget\x18\x06 \x01(\x0b\x32\'.yandex.cloud.billing.v1.CostBudgetSpecH\x00\x12\x44\n\x0e\x65xpense_budget\x18\x07 \x01(\x0b\x32*.yandex.cloud.billing.v1.ExpenseBudgetSpecH\x00\x12\x44\n\x0e\x62\x61lance_budget\x18\x08 \x01(\x0b\x32*.yandex.cloud.billing.v1.BalanceBudgetSpecH\x00\x42\x13\n\x0b\x62udget_spec\x12\x04\xc0\xc1\x31\x01\"\xd7\x02\n\x0e\x43ostBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xda\x02\n\x11\x45xpenseBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.yandex.cloud.billing.v1.ConsumptionFilter\x12@\n\x0creset_period\x18\x05 \x01(\x0e\x32(.yandex.cloud.billing.v1.ResetPeriodTypeH\x00\x12\x14\n\nstart_date\x18\x06 \x01(\tH\x00\x12\x16\n\x08\x65nd_date\x18\x07 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x12\n\nstart_type\x12\x04\xc0\xc1\x31\x01\"\xc6\x01\n\x11\x42\x61lanceBudgetSpec\x12\x14\n\x06\x61mount\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\x1dnotification_user_account_ids\x18\x02 \x03(\tB\x07\x82\xc8\x31\x03>=1\x12?\n\x0fthreshold_rules\x18\x03 \x03(\x0b\x32&.yandex.cloud.billing.v1.ThresholdRule\x12\x12\n\nstart_date\x18\x04 \x01(\t\x12\x16\n\x08\x65nd_date\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\"\x7f\n\x11\x43onsumptionFilter\x12\x13\n\x0bservice_ids\x18\x01 \x03(\t\x12U\n\x15\x63loud_folders_filters\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.billing.v1.CloudFoldersConsumptionFilter\"E\n\x1d\x43loudFoldersConsumptionFilter\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x12\n\nfolder_ids\x18\x02 \x03(\t\"\x88\x01\n\rThresholdRule\x12:\n\x04type\x18\x01 \x01(\x0e\x32&.yandex.cloud.billing.v1.ThresholdTypeB\x04\xe8\xc7\x31\x01\x12\x14\n\x06\x61mount\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x1dnotification_user_account_ids\x18\x03 \x03(\t*U\n\x0c\x42udgetStatus\x12\x1d\n\x19\x42UDGET_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x46INISHED\x10\x03*\\\n\x0fResetPeriodType\x12!\n\x1dRESET_PERIOD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\x0b\n\x07QUARTER\x10\x02\x12\x0c\n\x08\x41NNUALLY\x10\x03*H\n\rThresholdType\x12\x1e\n\x1aTHRESHOLD_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\x12\n\n\x06\x41MOUNT\x10\x02\x42\x62\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.budget_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _BUDGET.oneofs_by_name['budget_spec']._options = None
  _BUDGET.oneofs_by_name['budget_spec']._serialized_options = b'\300\3011\001'
  _COSTBUDGETSPEC.oneofs_by_name['start_type']._options = None
  _COSTBUDGETSPEC.oneofs_by_name['start_type']._serialized_options = b'\300\3011\001'
  _COSTBUDGETSPEC.fields_by_name['amount']._options = None
  _COSTBUDGETSPEC.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _COSTBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
  _COSTBUDGETSPEC.fields_by_name['notification_user_account_ids']._serialized_options = b'\202\3101\003>=1'
  _COSTBUDGETSPEC.fields_by_name['end_date']._options = None
  _COSTBUDGETSPEC.fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']._options = None
  _EXPENSEBUDGETSPEC.oneofs_by_name['start_type']._serialized_options = b'\300\3011\001'
  _EXPENSEBUDGETSPEC.fields_by_name['amount']._options = None
  _EXPENSEBUDGETSPEC.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _EXPENSEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
  _EXPENSEBUDGETSPEC.fields_by_name['notification_user_account_ids']._serialized_options = b'\202\3101\003>=1'
  _EXPENSEBUDGETSPEC.fields_by_name['end_date']._options = None
  _EXPENSEBUDGETSPEC.fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _BALANCEBUDGETSPEC.fields_by_name['amount']._options = None
  _BALANCEBUDGETSPEC.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _BALANCEBUDGETSPEC.fields_by_name['notification_user_account_ids']._options = None
  _BALANCEBUDGETSPEC.fields_by_name['notification_user_account_ids']._serialized_options = b'\202\3101\003>=1'
  _BALANCEBUDGETSPEC.fields_by_name['end_date']._options = None
  _BALANCEBUDGETSPEC.fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _THRESHOLDRULE.fields_by_name['type']._options = None
  _THRESHOLDRULE.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _THRESHOLDRULE.fields_by_name['amount']._options = None
  _THRESHOLDRULE.fields_by_name['amount']._serialized_options = b'\350\3071\001'
  _globals['_BUDGETSTATUS']._serialized_start=1757
  _globals['_BUDGETSTATUS']._serialized_end=1842
  _globals['_RESETPERIODTYPE']._serialized_start=1844
  _globals['_RESETPERIODTYPE']._serialized_end=1936
  _globals['_THRESHOLDTYPE']._serialized_start=1938
  _globals['_THRESHOLDTYPE']._serialized_end=2010
  _globals['_BUDGET']._serialized_start=130
  _globals['_BUDGET']._serialized_end=520
  _globals['_COSTBUDGETSPEC']._serialized_start=523
  _globals['_COSTBUDGETSPEC']._serialized_end=866
  _globals['_EXPENSEBUDGETSPEC']._serialized_start=869
  _globals['_EXPENSEBUDGETSPEC']._serialized_end=1215
  _globals['_BALANCEBUDGETSPEC']._serialized_start=1218
  _globals['_BALANCEBUDGETSPEC']._serialized_end=1416
  _globals['_CONSUMPTIONFILTER']._serialized_start=1418
  _globals['_CONSUMPTIONFILTER']._serialized_end=1545
  _globals['_CLOUDFOLDERSCONSUMPTIONFILTER']._serialized_start=1547
  _globals['_CLOUDFOLDERSCONSUMPTIONFILTER']._serialized_end=1616
  _globals['_THRESHOLDRULE']._serialized_start=1619
  _globals['_THRESHOLDRULE']._serialized_end=1755
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.loadbalancer.v1 import network_load_balancer_pb2 as yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2
from yandex.cloud.loadbalancer.v1 import network_load_balancer_service_pb2 as yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class NetworkLoadBalancerServiceStub(object):
    """A set of methods for managing NetworkLoadBalancer resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Get',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetNetworkLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2.NetworkLoadBalancer.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/List',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Create',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.CreateNetworkLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Update',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.UpdateNetworkLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Delete',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DeleteNetworkLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Start',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StartNetworkLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Stop = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Stop',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StopNetworkLoadBalancerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AttachTargetGroup = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/AttachTargetGroup',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AttachNetworkLoadBalancerTargetGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DetachTargetGroup = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/DetachTargetGroup',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DetachNetworkLoadBalancerTargetGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetTargetStates = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/GetTargetStates',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesResponse.FromString,
                )
        self.AddListener = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/AddListener',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AddNetworkLoadBalancerListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveListener = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/RemoveListener',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.RemoveNetworkLoadBalancerListenerRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsResponse.FromString,
                )


class NetworkLoadBalancerServiceServicer(object):
    """A set of methods for managing NetworkLoadBalancer resources.
    """

    def Get(self, request, context):
        """Returns the specified NetworkLoadBalancer resource.

        Get the list of available NetworkLoadBalancer resources by making a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of NetworkLoadBalancer resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a network load balancer in the specified folder using the data specified in the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Starts load balancing and health checking with the specified network load balancer with specified settings.
        Changes network load balancer status to `` ACTIVE ``.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops load balancing and health checking with the specified network load balancer.
        Changes load balancer status to `` STOPPED ``.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachTargetGroup(self, request, context):
        """Attaches a target group to the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachTargetGroup(self, request, context):
        """Detaches the target group from the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTargetStates(self, request, context):
        """Gets states of target resources in the attached target group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddListener(self, request, context):
        """Adds a listener to the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveListener(self, request, context):
        """Removes the listener from the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified network load balancer.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NetworkLoadBalancerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetNetworkLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2.NetworkLoadBalancer.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.CreateNetworkLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.UpdateNetworkLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DeleteNetworkLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StartNetworkLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StopNetworkLoadBalancerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AttachTargetGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachTargetGroup,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AttachNetworkLoadBalancerTargetGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DetachTargetGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachTargetGroup,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DetachNetworkLoadBalancerTargetGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetTargetStates': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTargetStates,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesResponse.SerializeToString,
            ),
            'AddListener': grpc.unary_unary_rpc_method_handler(
                    servicer.AddListener,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AddNetworkLoadBalancerListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveListener': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveListener,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.RemoveNetworkLoadBalancerListenerRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NetworkLoadBalancerService(object):
    """A set of methods for managing NetworkLoadBalancer resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Get',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetNetworkLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__pb2.NetworkLoadBalancer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/List',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersRequest.SerializeToString,
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Create',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.CreateNetworkLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Update',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.UpdateNetworkLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Delete',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DeleteNetworkLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Start',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StartNetworkLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/Stop',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.StopNetworkLoadBalancerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AttachTargetGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/AttachTargetGroup',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AttachNetworkLoadBalancerTargetGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachTargetGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/DetachTargetGroup',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.DetachNetworkLoadBalancerTargetGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTargetStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/GetTargetStates',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesRequest.SerializeToString,
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.GetTargetStatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/AddListener',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.AddNetworkLoadBalancerListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveListener(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/RemoveListener',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.RemoveNetworkLoadBalancerListenerRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.loadbalancer.v1.NetworkLoadBalancerService/ListOperations',
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_loadbalancer_dot_v1_dot_network__load__balancer__service__pb2.ListNetworkLoadBalancerOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/format_schema_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import format_schema_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_format__schema__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/mdb/clickhouse/v1/format_schema_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x32yandex/cloud/mdb/clickhouse/v1/format_schema.proto\"v\n\x16GetFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"z\n\x18ListFormatSchemasRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"z\n\x19ListFormatSchemasResponse\x12\x44\n\x0e\x66ormat_schemas\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.clickhouse.v1.FormatSchema\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x01\n\x19\x43reateFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x44\n\x04type\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.mdb.clickhouse.v1.FormatSchemaTypeB\x04\xe8\xc7\x31\x01\x12\x11\n\x03uri\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\"L\n\x1a\x43reateFormatSchemaMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1a\n\x12\x66ormat_schema_name\x18\x02 \x01(\t\"\xb7\x01\n\x19UpdateFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0b\n\x03uri\x18\x04 \x01(\t\"L\n\x1aUpdateFormatSchemaMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1a\n\x12\x66ormat_schema_name\x18\x02 \x01(\t\"y\n\x19\x44\x65leteFormatSchemaRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12:\n\x12\x66ormat_schema_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"L\n\x1a\x44\x65leteFormatSchemaMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1a\n\x12\x66ormat_schema_name\x18\x02 \x01(\t2\xea\x08\n\x13\x46ormatSchemaService\x12\xc4\x01\n\x03Get\x12\x36.yandex.cloud.mdb.clickhouse.v1.GetFormatSchemaRequest\x1a,.yandex.cloud.mdb.clickhouse.v1.FormatSchema\"W\x82\xd3\xe4\x93\x02Q\x12O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}\x12\xbf\x01\n\x04List\x12\x38.yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasRequest\x1a\x39.yandex.cloud.mdb.clickhouse.v1.ListFormatSchemasResponse\"B\x82\xd3\xe4\x93\x02<\x12:/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas\x12\xdb\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.clickhouse.v1.CreateFormatSchemaRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2**\n\x1a\x43reateFormatSchemaMetadata\x12\x0c\x46ormatSchema\x82\xd3\xe4\x93\x02?\":/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas:\x01*\x12\xf1\x01\n\x06Update\x12\x39.yandex.cloud.mdb.clickhouse.v1.UpdateFormatSchemaRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\xb2\xd2**\n\x1aUpdateFormatSchemaMetadata\x12\x0c\x46ormatSchema\x82\xd3\xe4\x93\x02T2O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}:\x01*\x12\xf7\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.clickhouse.v1.DeleteFormatSchemaRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*3\n\x1a\x44\x65leteFormatSchemaMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02Q*O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _GETFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
  _GETFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
  _GETFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _LISTFORMATSCHEMASREQUEST.fields_by_name['cluster_id']._options = None
  _LISTFORMATSCHEMASREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFORMATSCHEMASREQUEST.fields_by_name['page_size']._options = None
  _LISTFORMATSCHEMASREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTFORMATSCHEMASREQUEST.fields_by_name['page_token']._options = None
  _LISTFORMATSCHEMASREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['type']._options = None
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['type']._serialized_options = b'\350\3071\001'
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['uri']._options = None
  _CREATEFORMATSCHEMAREQUEST.fields_by_name['uri']._serialized_options = b'\350\3071\001'
  _UPDATEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
  _UPDATEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _DELETEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEFORMATSCHEMAREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._options = None
  _DELETEFORMATSCHEMAREQUEST.fields_by_name['format_schema_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _FORMATSCHEMASERVICE.methods_by_name['Get']._options = None
  _FORMATSCHEMASERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002Q\022O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}'
  _FORMATSCHEMASERVICE.methods_by_name['List']._options = None
  _FORMATSCHEMASERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002<\022:/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas'
  _FORMATSCHEMASERVICE.methods_by_name['Create']._options = None
  _FORMATSCHEMASERVICE.methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateFormatSchemaMetadata\022\014FormatSchema\202\323\344\223\002?\":/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas:\001*'
  _FORMATSCHEMASERVICE.methods_by_name['Update']._options = None
  _FORMATSCHEMASERVICE.methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateFormatSchemaMetadata\022\014FormatSchema\202\323\344\223\002T2O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}:\001*'
  _FORMATSCHEMASERVICE.methods_by_name['Delete']._options = None
  _FORMATSCHEMASERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteFormatSchemaMetadata\022\025google.protobuf.Empty\202\323\344\223\002Q*O/managed-clickhouse/v1/clusters/{cluster_id}/formatSchemas/{format_schema_name}'
  _globals['_GETFORMATSCHEMAREQUEST']._serialized_start=315
  _globals['_GETFORMATSCHEMAREQUEST']._serialized_end=433
  _globals['_LISTFORMATSCHEMASREQUEST']._serialized_start=435
  _globals['_LISTFORMATSCHEMASREQUEST']._serialized_end=557
  _globals['_LISTFORMATSCHEMASRESPONSE']._serialized_start=559
  _globals['_LISTFORMATSCHEMASRESPONSE']._serialized_end=681
  _globals['_CREATEFORMATSCHEMAREQUEST']._serialized_start=684
  _globals['_CREATEFORMATSCHEMAREQUEST']._serialized_end=894
  _globals['_CREATEFORMATSCHEMAMETADATA']._serialized_start=896
  _globals['_CREATEFORMATSCHEMAMETADATA']._serialized_end=972
  _globals['_UPDATEFORMATSCHEMAREQUEST']._serialized_start=975
  _globals['_UPDATEFORMATSCHEMAREQUEST']._serialized_end=1158
  _globals['_UPDATEFORMATSCHEMAMETADATA']._serialized_start=1160
  _globals['_UPDATEFORMATSCHEMAMETADATA']._serialized_end=1236
  _globals['_DELETEFORMATSCHEMAREQUEST']._serialized_start=1238
  _globals['_DELETEFORMATSCHEMAREQUEST']._serialized_end=1359
  _globals['_DELETEFORMATSCHEMAMETADATA']._serialized_start=1361
  _globals['_DELETEFORMATSCHEMAMETADATA']._serialized_end=1437
  _globals['_FORMATSCHEMASERVICE']._serialized_start=1440
  _globals['_FORMATSCHEMASERVICE']._serialized_end=2570
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/mongo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/datatransfer/v1/endpoint/mongo.proto\x12%yandex.cloud.datatransfer.v1.endpoint\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\"\x8a\x01\n\x0eOnPremiseMongo\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12\x13\n\x0breplica_set\x18\x05 \x01(\t\x12@\n\x08tls_mode\x18\x06 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.endpoint.TLSModeJ\x04\x08\x03\x10\x05\"\xee\x01\n\x16MongoConnectionOptions\x12\x18\n\x0emdb_cluster_id\x18\x01 \x01(\tH\x00\x12K\n\non_premise\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.OnPremiseMongoH\x00\x12\x0c\n\x04user\x18\x03 \x01(\t\x12?\n\x08password\x18\x04 \x01(\x0b\x32-.yandex.cloud.datatransfer.v1.endpoint.Secret\x12\x13\n\x0b\x61uth_source\x18\x05 \x01(\tB\t\n\x07\x61\x64\x64ress\"\x82\x01\n\x0fMongoConnection\x12[\n\x12\x63onnection_options\x18\x03 \x01(\x0b\x32=.yandex.cloud.datatransfer.v1.endpoint.MongoConnectionOptionsH\x00\x42\x0c\n\nconnectionJ\x04\x08\x01\x10\x03\"A\n\x0fMongoCollection\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x17\n\x0f\x63ollection_name\x18\x02 \x01(\t\"\xd6\x02\n\x0bMongoSource\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoConnection\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12K\n\x0b\x63ollections\x18\x06 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoCollection\x12T\n\x14\x65xcluded_collections\x18\x07 \x03(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoCollection\x12 \n\x18secondary_preferred_mode\x18\x08 \x01(\x08\x12\x17\n\x0fsecurity_groups\x18\x0b \x03(\tJ\x04\x08\x03\x10\x06J\x04\x08\t\x10\x0b\"\xeb\x01\n\x0bMongoTarget\x12J\n\nconnection\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.datatransfer.v1.endpoint.MongoConnection\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12L\n\x0e\x63leanup_policy\x18\x06 \x01(\x0e\x32\x34.yandex.cloud.datatransfer.v1.endpoint.CleanupPolicy\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x08 \x03(\tJ\x04\x08\x03\x10\x06\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.mongo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_ONPREMISEMONGO']._serialized_start=145
  _globals['_ONPREMISEMONGO']._serialized_end=283
  _globals['_MONGOCONNECTIONOPTIONS']._serialized_start=286
  _globals['_MONGOCONNECTIONOPTIONS']._serialized_end=524
  _globals['_MONGOCONNECTION']._serialized_start=527
  _globals['_MONGOCONNECTION']._serialized_end=657
  _globals['_MONGOCOLLECTION']._serialized_start=659
  _globals['_MONGOCOLLECTION']._serialized_end=724
  _globals['_MONGOSOURCE']._serialized_start=727
  _globals['_MONGOSOURCE']._serialized_end=1069
  _globals['_MONGOTARGET']._serialized_start=1072
  _globals['_MONGOTARGET']._serialized_end=1307
# @@protoc_insertion_point(module_scope)
